#
# spec file for package xournal
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xournal
Version:        0.4.8.2016
Release:        lp151.3.3
Summary:        An application for notetaking, sketching, and keeping a journal using a stylus
License:        GPL-2.0-or-later
Group:          Productivity/Office/Other
Url:            http://xournal.sourceforge.net/
Source:         http://download.sf.net/xournal/%{name}-%{version}.tar.gz
Patch0:         %{name}-implicit-funcs.patch
# PATCH-FIX-UPSTREAM xournal-Improve-window-title.patch -- https://sourceforge.net/p/xournal/patches/79/
Patch1:         %{name}-Improve-window-title.patch
# PATCH-FIX-UPSTREAM xournal-appdata.patch badshah400@gmail.com -- Add, translate and install appdata file
Patch2:         xournal-appdata.patch
# PATCH-FIX-UPSTREAM xournal-fix-strokes-on-Lenovo-active-pen.patch badshah400@gmail.com -- Fix strokes with Lenovo active pen 2; patches taken from upstream git
Patch3:         xournal-fix-strokes-on-Lenovo-active-pen.patch
BuildRequires:  automake >= 1.11.2
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  inkscape
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-x11-2.0)
BuildRequires:  pkgconfig(libart-2.0)
BuildRequires:  pkgconfig(libgnomecanvas-2.0)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(pangoft2)
BuildRequires:  pkgconfig(poppler-glib)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(zlib)

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Xournal is an application for notetaking, sketching, and keeping a journal
using a stylus. You can also use it to annotate PDF files with scribbles or
text. It works similarly to applications like Microsoft Windows Journal or
Jarnal.
It is free software (GNU GPL) and runs on Linux and other GTK+/Gnome platforms. 

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1

%build
autoreconf -fi
intltoolize --force
%configure
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
make DESTDIR=%{buildroot} desktop-install

# GENERATE AND INSTALL HIRES ICONS IN HICOLOR ICON DIR
for i in 24 32 48 64 128 256
do
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/mimetypes
  inkscape -w ${i} -C pixmaps/%{name}.svg \
           -e %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
  inkscape -w ${i} -C pixmaps/xoj.svg \
           -e %{buildroot}%{_datadir}/icons/hicolor/${i}x${i}/mimetypes/application-x-xoj.png
done

%suse_update_desktop_file %{name}
%find_lang %{name}

install -D -m 0644 %{name}.xml %{buildroot}%{_datadir}/mime/application/x-xoj.xml
mkdir -p %{buildroot}%{_docdir}/%{name}
install -m 0644 -t %{buildroot}%{_docdir}/%{name} AUTHORS COPYING ChangeLog NEWS README

%fdupes %{buildroot}%{_datadir}

%post
%desktop_database_post
%icon_theme_cache_post
%mime_database_post

%postun
%desktop_database_postun
%icon_theme_cache_postun
%mime_database_postun

%files -f %{name}.lang
%defattr(-, root, root)
%doc %{_docdir}/%{name}
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/appdata/%{name}.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/icons/hicolor/*/mimetypes/*xoj.*
%{_datadir}/mime/packages/xournal.xml
%{_datadir}/mime/application/x-xoj.xml
%dir %{_datadir}/mimelnk
%dir %{_datadir}/mimelnk/application
%{_datadir}/mimelnk/application/x-xoj.desktop
%if 0%{?suse_version} < 1320
%dir %{_datadir}/appdata
%endif

%changelog
* Sat Feb 24 2018 crrodriguez@opensuse.org
- Fix BuildRequires so it lists all the needed, specific
  libraries.
* Sat Nov 11 2017 badshah400@gmail.com
- Switch BuildRequires to pkgconfig based ones wherever possible.
* Sat Sep 30 2017 badshah400@gmail.com
- Add xournal-fix-strokes-on-Lenovo-active-pen.patch: Fix strokes
  with Lenovo active pen 2; patches taken from upstream git.
* Thu Jul 20 2017 rpm@fthiessen.de
- Dropped upstream merged xournal-german-translation.patch
* Thu Jul 20 2017 badshah400@gmail.com
- Update to version 0.4.8.2016:
  * Pen and touchscreen input handling bugfixes (bug #136 and
    others).
  * Fix a minor bug with save file paths in Windows.
  * Use GDK macros (not WIN32) to disable X11-specific code (T.
    Schoonjans)
  * Export to PDF and printing: fix resolution loss on some pdf
    backgrounds.
  * Disable xinput during modal dialog boxes (bug #159).
  * Avoid data corruption when exporting to overwrite a PDF.
  * Fix path search order for toolbar bitmaps.
  * Text and image tools activate on button release instead of
    button press to avoid subsequent confusion between clicks in
    toolbar and drawing area.
  * Fix "pen disable touch" when touchscreen sends prox events.
  * Fix crash when pasting text or images via xclip (bug #171).
  * Add space and shift-space bindings to page down/up.
  * Add A5 paper.
  * Config option to export successive layers to separate PDF.
    pages.
  * Config option to create new file when trying to open
    non-existent .xoj.
  * Updated translations.
- Use full URL for source tarball.
- Drop xournal-decl-spec.patch; upstreamed.
- Minor rebase of patches where needed.
* Mon Jun 12 2017 rpm@fthiessen.de
- Fixed build with Tumbleweed by adding xournal-decl-spec.patch
* Fri Dec 16 2016 sknorr@suse.com
- Improve package description
* Fri Aug  5 2016 rpm@fthiessen.de
- Some cleanup on the spec-file.
* Fri Aug  5 2016 badshah400@gmail.com
- Add xournal-appdata.patch to add, translate and install appdata
  file for application, this makes xournal show up in appstores
  like GNOME Software and KDE Discover; run intltoolize to
  translate appdata file.
* Mon Jul  6 2015 badshah400@gmail.com
- Use upstream command to install desktop entries, mimetypes
  and icons.
- Generate and install hires icons into hicolor directory (needed
  on HiDPI displays).
- Use appropriate post-scripts to update desstop menu database,
  mime cache and icon-theme.
- Drop external .desktop file and icon, and use upstream bundled
  ones.
* Sun Mar 22 2015 rpm@fthiessen.de
- Improved spec file (requirements)
* Tue Mar  3 2015 rpm@fthiessen.de
- Added some patches
  * Missing German translation: xournal-german-translation.patch
  * Window title format is corrected: xournal-Improve-window-title.patch
- incorrect-fsf-address warning is reported upstream (Bug #151)
* Tue Mar  3 2015 rpm@fthiessen.de
- Updated to 0.4.8
- removed outdated patch (now included in xournal)
  * xournal-large-pen-cursor.patch
* Mon Mar  2 2015 rpm@fthiessen.de
- slightly modified changlog, so factory auto review does not grumble anymore.
  * Added patch references
* Wed Jul 24 2013 Rene.vanPaassen@gmail.com
- have the large pen cursor option updated in the interface after defaults
  loaded
* Tue Jul 23 2013 Rene.vanPaassen@gmail.com
- don't need libgnomeprintui
* Tue Jul 23 2013 Rene.vanPaassen@gmail.com
- update to 0.4.7, and add a patch to optionally select a larger cursor
  * xournal-large-pen-cursor.patch
- added patch for fixing implicit functions
  * xournal-implicit-funcs.patch
- removed unneeded patches (which are now included in xournal)
  * xournal-automake-1.13.patch
  * xournal-poppler-0.18.patch
  * xournal-unistd-decl.diff
  * xournal-no-copy-dt-needed-entries.patch
* Wed Mar 13 2013 pgajdos@suse.cz
- builds with automake 1.13
  * automake-1.13.patch
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Sep 20 2011 vuntz@opensuse.org
- Add xournal-poppler-0.18.patch: fix build with poppler 0.18.
  Taken from CVS.
* Fri Sep 16 2011 suse-tux@gmx.de
- added "-lm" to no-copy-dt-needed-entries.patch (fix factory build)
* Tue Aug 30 2011 pgajdos@suse.com
- build with --no-copy-dt-needed-entries
  * no-copy-dt-needed-entries.patch
* Fri May 14 2010 prusnak@suse.cz
- cleanup spec file
* Fri May  7 2010 sharms@ubuntu.com
- Update to version 0.4.5:
  - bugfixes for GTK+ 2.16/2.17 issues with xinput events
  - various minor UI bugfixes
  - gettext internationalization (contributed by David Planella)
  - Catalan translation (by David Planella), French translation
  - use poppler instead of pdftoppm to render PDF backgrounds
    (after patches by Mike Ter Louw and Bob McElrath)
  - various improvements to UI and to key bindings (including
    patches by Bob McElrath and Lu Zhihe)
  - use gtk-print instead of libgnomeprint for printing
  - custom color chooser (patch contributed by Alex Ray)
  - option to have tablet buttons toggle the mapping rather than draw
  - paper color chooser (after a patch by Ole Joergen Broenner)
  - remove binary installer (due to binary incompatibilities)
  - UPDATED DEPENDENCIES: need gtk+ 2.10, poppler-glib 0.5.4
* Fri Apr 11 2008 dkukawka@suse.de
- updated to new 0.4.2.1:
  - bugfix for #1926757 (crash upon pasting variable-width stroke)
  - bugfix: set ruler/recognizer setting to default upon switching
    tools
  - bugfixes for X.org 7.3; allow XInput and core events in reverse
    order
  - resize selection
  - pressure sensitive pen (variable stroke width)
  - geometric shape recognizer (see manual)
  - clean up compiler warnings (patch contributed by Danny Kukawka)
- removed upstream gone patches:
  - xournal-fix-compilerWarnings.diff
  - xournal-retval.patch
* Thu Sep 27 2007 dkukawka@suse.de
- updated to new upstream version 0.4.1:
  - bugfix: compatibility with new versions of pdftoppm
  - GTK+ 2.11 event processing bugfix
  - minor bugfixes: hand tool, handling of filenames containing '&'
  - desktop and MIME files + updated installer
  - config options: left-handed scrollbar, hide some menu items
    (customizable in config file), auto-save preferences
  - bugfixes for GTK+ 2.11 behavior
  - text tool (handles most TrueType and Type1 fonts)
  - font selection dialog and button
  - keyboard mappings (arrow keys)
  - menu mnemonics and shortcuts
  - more responsive hand tool
  - bugfix for GTK+ 2.11 XInput behavior
  - various minor bugfixes and enhancements
- added patch:
  - xournal-fix-compilerWarnings.diff (fix really many compiler
    warnings and 64bit issues)
* Thu Mar  8 2007 dkukawka@suse.de
- updated to new upstream version 0.3.3:
  - bugfix: upon loading a new file, zoom is set to default
    startup zoom
  - config option to allow input from a mouse or other core pointer
    device
  - config file entry to specify a default location for open/save
    (patch contributed by Andy Neitzke)
  - config file entries to customize visibility and position of
    toolbars
  - icon (thanks to Michele Codutti)
- added new icon for the desktop file
* Mon Jan  8 2007 dkukawka@suse.de
- updated to new upstream version 0.3.2:
  - preferences file and Save Preferences command
  - extra customization (via preferences file)
  - minor UI changes (patch contributed by Eduardo de Barros Lima)
  - hand tool (partially contributed by Vincenzo Ciancia)
  - a few bugfixes in rendering of bitmap backgrounds
  - fixed a file format bug on systems with non-standard numeric
    locale (bug reported by Gert Renckens)
- fixed b.n.c #222484
* Sun Nov 12 2006 stbinner@suse.de
- don't repeat Name in GenericName field within .desktop file
* Wed Sep 13 2006 ro@suse.de
- fix a missing return value in nonvoid function
* Wed Jul 26 2006 dkukawka@suse.de
- updated to current upstream version 0.3:
  - new PDF rendering engine: export to PDF generates optimized files
    (smaller and more accurate)
  - export to PDF handles PDF backgrounds (up to PDF-1.4) natively
    (without conversion to bitmap)
  - default thickness of erasers and highlighters slightly increased
  - zoom dialog box with input box and "fit to page height" option
  - file format documentation added to the user's manual
* Mon Jul  3 2006 dkukawka@suse.de
- updated to current upstream version 0.2.2:
  * Version 0.2.2 (Jun 5, 2006):
  - mapping of tools to stylus buttons (the options menu has new
    entries to allow the mapping of buttons 2 and 3 to arbitrary
    tools; the tools menu and toolbar affect the settings for
    button 1) (see manual)
  - moving selection by drag-and-drop works across page
    boundaries
  - vertical space tool can move items to next page (only when
    the entire block being moved has crossed the page boundary;
    items on the new page are not moved) - "apply to all pages"
    is now a toggle button affecting the behavior of paper size,
    color, and style commands
  - change in the behavior of the selection upon switching
    between tools
  * Version 0.2.1 (Jun 3, 2006):
  - recently used files listed in file menu
  - can change color or thickness of pen strokes in selection
  - function to apply paper style to all pages
  - can specify on command line a PDF file to annotate
  - suggest a derived file name for PDF annotation
  - speed up switching between pages
  - fixed a bug in XInput initialization (thanks to Luca de Cicco)
  - fixed a bug in print ranges (thanks to Mathieu Bouchard)
  - fixed a refresh bug in rescaling bitmap backgrounds
* Thu Feb  2 2006 dkukawka@suse.de
- init version 0.2
  - added icon and desktop file
